import Prefix from './prefix';
import IpBits from './ip_bits';
import Crunchy from './crunchy';
export interface Is {
    (source: IPAddress): boolean;
}
export interface ToIpv4 {
    (source: IPAddress): IPAddress;
}
export interface EachFn {
    (source: IPAddress): void;
}
export declare class ResultCrunchyParts {
    crunchy: Crunchy;
    parts: number;
    constructor(crunchy: Crunchy, parts: number);
}
export declare class IPAddress {
    ip_bits: IpBits;
    host_address: Crunchy;
    prefix: Prefix;
    mapped: IPAddress;
    vt_is_private: Is;
    vt_is_loopback: Is;
    vt_to_ipv6: ToIpv4;
    constructor(obj: {
        [id: string]: any;
    });
    clone(): IPAddress;
    lt(oth: IPAddress): boolean;
    lte(oth: IPAddress): boolean;
    gt(oth: IPAddress): boolean;
    gte(oth: IPAddress): boolean;
    cmp(oth: IPAddress): number;
    eq(other: IPAddress): boolean;
    ne(other: IPAddress): boolean;
    static parse(str: string): IPAddress;
    static split_at_slash(str: string): [string, string];
    from(addr: Crunchy, prefix: Prefix): IPAddress;
    is_ipv4(): boolean;
    is_ipv6(): boolean;
    static is_valid(addr: string): boolean;
    static parse_dec_str(str: string): number;
    static parse_hex_str(str: string): number;
    static parse_ipv4_part(i: string): number;
    static split_to_u32(addr: string): Crunchy;
    static is_valid_ipv4(addr: string): boolean;
    static split_on_colon(addr: string): ResultCrunchyParts;
    static split_to_num(addr: string): ResultCrunchyParts;
    static is_valid_ipv6(addr: string): boolean;
    static pos_to_idx(pos: number, len: number): number;
    static aggregate(networks: IPAddress[]): IPAddress[];
    parts(): number[];
    parts_hex_str(): string[];
    dns_rev_domains(): string[];
    dns_reverse(): string;
    dns_parts(): number[];
    dns_networks(): IPAddress[];
    static summarize(networks: IPAddress[]): IPAddress[];
    static summarize_str(netstr: string[]): IPAddress[];
    ip_same_kind(oth: IPAddress): boolean;
    is_unspecified(): boolean;
    is_loopback(): boolean;
    is_mapped(): boolean;
    static is_valid_netmask(addr: string): boolean;
    static netmask_to_prefix(nm: Crunchy, bits: number): number;
    static parse_netmask_to_prefix(netmask: string): number;
    change_prefix(num: number): IPAddress;
    change_netmask(str: string): IPAddress;
    to_string(): string;
    to_s(): string;
    to_string_uncompressed(): string;
    to_s_uncompressed(): string;
    to_s_mapped(): string;
    to_string_mapped(): string;
    bits(): string;
    to_hex(): string;
    netmask(): IPAddress;
    broadcast(): IPAddress;
    is_network(): boolean;
    network(): IPAddress;
    static to_network(adr: Crunchy, host_prefix: number): Crunchy;
    sub(other: IPAddress): Crunchy;
    add(other: IPAddress): IPAddress[];
    static to_s_vec(vec: IPAddress[]): string[];
    static to_string_vec(vec: IPAddress[]): string[];
    static to_ipaddress_vec(vec: string[]): IPAddress[];
    first(): IPAddress;
    last(): IPAddress;
    each_host(func: EachFn): void;
    inc(): IPAddress;
    dec(): IPAddress;
    each(func: EachFn): void;
    size(): Crunchy;
    is_same_kind(oth: IPAddress): boolean;
    includes(oth: IPAddress): boolean;
    includes_all(oths: [IPAddress]): boolean;
    is_private(): boolean;
    sum_first_found(arr: IPAddress[]): IPAddress[];
    split(subnets: number): IPAddress[];
    supernet(new_prefix: number): IPAddress;
    subnet(subprefix: number): IPAddress[];
    to_ipv6(): IPAddress;
    newprefix(num: number): Prefix;
}
export default IPAddress;
